==> acquia_dam-1.0.0.tar.gz: acquia_dam/tests/src/Kernel/AcquiaDamKernelTestBase.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\acquia_dam\Kernel;

use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
use Drupal\media\Entity\MediaType;
use Drupal\user\UserInterface;

/**
 * Base test class for acquia_dam.
 *
 * @group acquia_dam
 */
abstract class AcquiaDamKernelTestBase extends EntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'views',
    'file',
    'image',
    'media',
    'media_library',
    'views_remote_data',
    'acquia_dam',
    'acquia_dam_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('file');
    $this->installEntitySchema('media');
    $this->installSchema('acquia_dam', ['acquia_dam_integration_link_tracking']);
    $this->installSchema('user', ['users_data']);
    $this->installSchema('file', 'file_usage');

    // Burn uid 1.
    $this->createUser();
  }

  /**
   * {@inheritdoc}
   */
  protected function drupalSetUpCurrentUser(array $values = [], array $permissions = [], $admin = FALSE): UserInterface {
    $user = parent::drupalSetUpCurrentUser($values, $permissions, $admin);
    $this->container->get('acquia_dam.authentication_service')->setUserData(
      (int) $user->id(),
      [
        'acquia_dam_username' => $user->getEmail(),
        'acquia_dam_token' => $this->randomString(),
      ]
    );
    return $user;
  }

  /**
   * Set a random string as mock site token for DAM.
   *
   * @throws \Exception
   */
  protected function setDamSiteToken() {
    $this
      ->container
      ->get('state')
      ->set('acquia_dam_token', $this->randomString());
  }

  /**
   * Creates a PDF media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createPdfMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:pdf');
  }

  /**
   * Creates a Video media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createVideoMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:video');
  }

  /**
   * Creates a Spinset media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createSpinsetMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:spinset');
  }

  /**
   * Creates an Image media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createImageMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:image');
  }

  /**
   * Creates a document media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createDocumentMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:documents');
  }

  /**
   * Creates a media type.
   *
   * @param string $source_plugin_id
   *   The plugin ID.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  private function createMediaType(string $source_plugin_id): MediaType {
    $media_type = MediaType::create([
      'id' => $this->randomMachineName(),
      'label' => $this->randomString(),
      'source' => $source_plugin_id,
    ]);
    $source = $media_type->getSource();
    $source_field = $source->createSourceField($media_type);
    $source_configuration = $source->getConfiguration();
    $source_configuration['source_field'] = $source_field->getName();
    $source->setConfiguration($source_configuration);
    $this->assertSame(SAVED_NEW, $media_type->save());
    return $media_type;
  }

  /**
   * Grants the site a dummy DAM domain.
   */
  protected function grantDamDomain() {
    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $configFactory->getEditable('acquia_dam.settings')
      ->set('domain', 'test.widencollective.com')
      ->save();
  }

}

==> acquia_dam-1.0.1.tar.gz: acquia_dam/tests/src/Kernel/AcquiaDamKernelTestBase.php <==
<?php

declare(strict_types=1);

namespace Drupal\Tests\acquia_dam\Kernel;

use Drupal\KernelTests\Core\Entity\EntityKernelTestBase;
use Drupal\media\Entity\MediaType;
use Drupal\user\UserInterface;

/**
 * Base test class for acquia_dam.
 *
 * @group acquia_dam
 */
abstract class AcquiaDamKernelTestBase extends EntityKernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'views',
    'file',
    'image',
    'media',
    'media_library',
    'views_remote_data',
    'acquia_dam',
    'acquia_dam_test',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->installEntitySchema('file');
    $this->installEntitySchema('media');
    $this->installSchema('acquia_dam', ['acquia_dam_integration_link_tracking', 'acquia_dam_integration_link_aggregate']);
    $this->installSchema('user', ['users_data']);
    $this->installSchema('file', 'file_usage');

    // Burn uid 1.
    $this->createUser();
  }

  /**
   * {@inheritdoc}
   */
  protected function drupalSetUpCurrentUser(array $values = [], array $permissions = [], $admin = FALSE): UserInterface {
    $user = parent::drupalSetUpCurrentUser($values, $permissions, $admin);
    $this->container->get('acquia_dam.authentication_service')->setUserData(
      (int) $user->id(),
      [
        'acquia_dam_username' => $user->getEmail(),
        'acquia_dam_token' => $this->randomString(),
      ]
    );
    return $user;
  }

  /**
   * Set a random string as mock site token for DAM.
   *
   * @throws \Exception
   */
  protected function setDamSiteToken() {
    $this
      ->container
      ->get('state')
      ->set('acquia_dam_token', $this->randomString());
  }

  /**
   * Creates a PDF media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createPdfMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:pdf');
  }

  /**
   * Creates a Video media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createVideoMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:video');
  }

  /**
   * Creates a Spinset media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createSpinsetMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:spinset');
  }

  /**
   * Creates an Image media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createImageMediaType(): MediaType {
    $media_type = $this->createMediaType('acquia_dam_asset:image');
    $media_type->setNewRevision(TRUE)->save();
    return $media_type;
  }

  /**
   * Creates a document media type.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  protected function createDocumentMediaType(): MediaType {
    return $this->createMediaType('acquia_dam_asset:documents');
  }

  /**
   * Creates a media type.
   *
   * @param string $source_plugin_id
   *   The plugin ID.
   *
   * @return \Drupal\media\Entity\MediaType
   *   The media type.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  private function createMediaType(string $source_plugin_id): MediaType {
    $media_type = MediaType::create([
      'id' => $this->randomMachineName(),
      'label' => $this->randomString(),
      'source' => $source_plugin_id,
      'queue_thumbnail_downloads' => FALSE,
    ]);
    $source = $media_type->getSource();
    $source_field = $source->createSourceField($media_type);
    $source_configuration = $source->getConfiguration();
    $source_configuration['source_field'] = $source_field->getName();
    $source->setConfiguration($source_configuration);
    $this->assertSame(SAVED_NEW, $media_type->save());
    return $media_type;
  }

  /**
   * Grants the site a dummy DAM domain.
   */
  protected function grantDamDomain() {
    /** @var \Drupal\Core\Config\ConfigFactoryInterface $configFactory */
    $configFactory = $this->container->get('config.factory');
    $configFactory->getEditable('acquia_dam.settings')
      ->set('domain', 'test.widencollective.com')
      ->save();
  }

}
